<header class="md-header" data-md-component="header">
  {% if config.extra.corner_logo %}
    <a href="{{ base_url }}">
      <div class="background-logo" style="background-image:url('{{ base_url }}/{{ config.extra.corner_logo }}');background-repeat:no-repeat;height:107px">
    {% endif %}
  <nav class="md-header-nav md-grid">
    <div class="md-flex">
      <div class="md-flex__cell md-flex__cell--shrink">
        <a href="{{ config.site_url | default(nav.homepage.url, true) }}" title="{{ config.site_name }}" class="md-header-nav__button md-logo">
          {% if config.extra.logo %}
            {% if config.extra.logo.icon %}
              <i class="md-icon">{{ config.extra.logo.icon }}</i>
            {% else %}
              <img src="{{ base_url }}/{{ config.extra.logo }}" width="24" height="24">
            {% endif %}
          {% else %}
            <i class="md-icon md-icon--home"></i>
          {% endif %}
        </a>
      </div>
      <div class="md-flex__cell md-flex__cell--shrink">
        <label class="md-icon md-icon--menu md-header-nav__button" for="drawer"></label>
      </div>
      <div class="md-flex__cell md-flex__cell--stretch">
        <span class="md-flex__ellipsis md-header-nav__title">
          {% block site_name %}
            {% if page %}
              {% for parent in page.ancestors %}
                <span class="md-header-nav__parent">
                  {{ parent.title }}
                </span>
              {% endfor %}
            {% endif %}
            {% if page.title == "Home" %}
              {{ config.site_name }}
            {% else %}
              {{ page.title }}
            {% endif %}
          {% endblock %}
        </span>
      </div>
      <div class="md-flex__cell md-flex__cell--shrink">
        {% block search_box %}
          <label class="md-icon md-icon--search md-header-nav__button" for="search"></label>
          {% include "partials/search.html" %}
        {% endblock %}
      </div>
      {% if config.repo_url %}
        <div class="md-flex__cell md-flex__cell--shrink">
          <div class="md-header-nav__source">
            {% include "partials/source.html" %}
          </div>
        </div>
      {% endif %}
    </div>
  </nav>
</header>
