<nav class="md-nav md-nav--primary" data-md-level="0">
  <label class="md-nav__title md-nav__title--site" for="drawer">
    <a href="{{ config.site_url | default(nav.homepage.url, true) | url }}" title="{{ config.site_name }}" class="md-nav__button md-logo">
      {% if config.extra.logo %}
        {% if config.extra.logo.icon %}
          <i class="md-icon">{{ config.extra.logo.icon }}</i>
        {% else %}
          <img src="{{ base_url }}/{{ config.extra.logo }}">
        {% endif %}
      {% else %}
        <i class="md-icon md-icon--home"></i>
      {% endif %}
    </a>
    {{ config.site_name }}
  </label>
  {% if config.repo_url %}
    <div class="md-nav__source">
      {% include "partials/source.html" %}
    </div>
  {% endif %}
  <ul class="md-nav__list" data-md-scrollfix>
    {% for nav_item in nav %}
      {% set path = "nav-" + loop.index | string %}
      {% set level = 1 %}
      {% include "partials/nav-item.html" %}
    {% endfor %}
  </ul>
</nav>
