{% set class = "md-nav__item" %}
{% if nav_item.active %}
  {% set class = "md-nav__item md-nav__item--active" %}
{% endif %}
{% if nav_item.children %}
  <li class="{{ class }} md-nav__item--nested">
    {% if nav_item.active %}
      <input class="md-toggle md-nav__toggle" data-md-toggle="{{ path }}" type="checkbox" id="{{ path }}" checked>
    {% else %}
      <input class="md-toggle md-nav__toggle" data-md-toggle="{{ path }}" type="checkbox" id="{{ path }}">
    {% endif %}
    <label class="md-nav__link" for="{{ path }}">
      {{ nav_item.title }}
    </label>
    <nav class="md-nav" data-md-component="collapsible" data-md-level="{{ level }}">
      <label class="md-nav__title" for="{{ path }}">
        {{ nav_item.title }}
      </label>
      <ul class="md-nav__list" data-md-scrollfix>
        {% set base = path %}
        {% for nav_item in nav_item.children %}
          {% set path = base + "-" + loop.index | string %}
          {% set level = level + 1 %}
          {% include "partials/nav-item.html"  %}
        {% endfor %}
      </ul>
    </nav>
  </li>
{% elif nav_item == page %}
  <li class="{{ class }}">
    {% set toc_ = page.toc %}
    <input class="md-toggle md-nav__toggle" data-md-toggle="toc" type="checkbox" id="toc">
    {% if toc_ | first is defined and "\x3ch1 id=" in page.content %}
      {% set toc_ = (toc_ | first).children %}
    {% endif %}
    {% if toc_ | first is defined %}
      <label class="md-nav__link md-nav__link--active" for="toc">
        {{ nav_item.title }}
      </label>
    {% endif %}
    <a href="{{ nav_item.url | url }}" title="{{ nav_item.title }}" class="md-nav__link md-nav__link--active">
      {{ nav_item.title }}
    </a>
    {% if toc_ | first is defined %}
      {% include "partials/toc.html" %}
    {% endif %}
  </li>
{% else %}
  <li class="{{ class }}">
    <a href="{{ nav_item.url | url }}" title="{{ nav_item.title }}" class="md-nav__link">
      {{ nav_item.title }}
    </a>
  </li>
{% endif %}
