{% import "partials/language.html" as lang %}
<nav class="md-nav md-nav--secondary">
  {% set toc_ = page.toc %}
  {% if toc_ | first is defined and "\x3ch1 id=" in page.content %}
    {% set toc_ = (toc_ | first).children %}
  {% endif %}
  {% if toc_ | first is defined %}
    <label class="md-nav__title" for="toc">{{ lang.t("toc.title") }}</label>
    <ul class="md-nav__list" data-md-scrollfix>
      {% for toc_item in toc_ %}
        {% include "partials/toc-item.html" %}
      {% endfor %}
      {% if page.meta.source and page.meta.source | length > 0 %}
        <li class="md-nav__item">
          <a href="#__source" title="{{ lang.t('meta.source') }}" class="md-nav__link md-nav__link--active">
            {{ lang.t("meta.source") }}
          </a>
        </li>
      {% endif %}
      {% if config.extra.disqus and not page.is_homepage %}
        <li class="md-nav__item">
          <a href="#__comments" title="{{ lang.t('meta.comments') }}" class="md-nav__link md-nav__link--active">
            {{ lang.t("meta.comments") }}
          </a>
        </li>
      {% endif %}
    </ul>
  {% endif %}
</nav>
