{% if nav_item.is_homepage %}
  <li class="md-tabs__item">
    {% if not page.ancestors | length and nav | selectattr("url", page.url) %}
      <a href="{{ nav_item.url }}" title="{{ nav_item.title }}" class="md-tabs__link md-tabs__link--active">
        {{ nav_item.title }}
      </a>
    {% else %}
      <a href="{{ nav_item.url }}" title="{{ nav_item.title }}" class="md-tabs__link">
        {{ nav_item.title }}
      </a>
    {% endif %}
  </li>
{% elif nav_item.children and nav_item.children | length > 0 %}
  {% set title = title | default(nav_item.title) %}
  {% if (nav_item.children | first).children | length > 0 %}
    {% set nav_item = nav_item.children | first %}
    {% include "partials/tabs-item.html" %}
  {% else %}
    <li class="md-tabs__item">
      {% if nav_item.active %}
        <a href="{{ (nav_item.children | first).url }}" title="{{ title }}" class="md-tabs__link md-tabs__link--active">
          {{ title }}
        </a>
      {% else %}
        <a href="{{ (nav_item.children | first).url }}" title="{{ title }}" class="md-tabs__link">
          {{ title }}
        </a>
      {% endif %}
    </li>
  {% endif %}
{% endif %}
